var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import React from 'react';
import PropTypes from 'prop-types';
import stylePropType from 'react-style-proptype';

/**
 * Creates a stepper.
 * @param {array} steps - Names of different steps.
 * @param {number} activeStep - Index of the active step.
 * @param {string} className - Classname of the component.
 * @param {string} styleComponent - Style of the component.
 * @param {string} styleStep - Style of the step box.
 * @param {string} styleLine - Style of the line between step boxes.
 * @param {string} styleActive - Active style step.
 * @returns {ReactElement} - Stepper generated
 */
var Stepper = function Stepper(_ref) {
  var steps = _ref.steps,
      activeStep = _ref.activeStep,
      className = _ref.className,
      styleComponent = _ref.styleComponent,
      styleStep = _ref.styleStep,
      styleLine = _ref.styleLine,
      styleActive = _ref.styleActive;

  var stepsLines = steps.reduce(function (r, a) {
    return r.concat(a, false);
  }, []);
  stepsLines.pop();

  return React.createElement(
    'div',
    { style: styleComponent, className: 'Stepper ' + className },
    stepsLines.map(function (step, i) {
      return i % 2 ? React.createElement('div', {
        key: i,
        style: _extends({}, styleLine, ++activeStep >= i ? styleActive : {})
      }) : React.createElement(
        'div',
        {
          key: i,
          style: _extends({}, styleStep, activeStep >= i ? styleActive : {})
        },
        step
      );
    })
  );
};

Stepper.propTypes = process.env.NODE_ENV !== "production" ? {
  // State
  steps: PropTypes.arrayOf(PropTypes.string).isRequired,
  activeStep: PropTypes.number.isRequired,

  // Modifiers
  className: PropTypes.string,
  styleComponent: stylePropType,
  styleStep: stylePropType,
  styleLine: stylePropType,
  styleActive: stylePropType
} : {};

Stepper.defaultProps = {
  // Modifiers
  className: '',
  styleComponent: {
    display: 'flex',
    justifyContent: 'space-around',
    flexFlow: 'row wrap',
    margin: '10px 20px',
    alignItems: 'center'
  },
  styleStep: {
    background: '#6e6e6e',
    color: '#fff',
    flexShrink: 1,
    padding: '10px 14px',
    borderRadius: '7px'
  },
  styleLine: {
    height: '2px',
    background: '#6e6e6e',
    flexGrow: 1
  },
  styleActive: {
    background: '#4f96ff'
  }
};

export default Stepper;